@@ -1,5 +1,5 @@
 """Functionality for instantiating the environment by passing the environment id."""
-from plangym.control import Box2DEnv, ClassicControl, DMControlEnv, LunarLander
+from plangym.control import BalloonEnv, Box2DEnv, ClassicControl, DMControlEnv, LunarLander
 from plangym.environment_names import ATARI, BOX_2D, CLASSIC_CONTROL, DM_CONTROL, RETRO
 from plangym.vectorization import ParallelEnv, RayEnv
 from plangym.videogames import AtariEnv, MarioEnv, MontezumaEnv, RetroEnv
@@ -27,6 +27,8 @@ def get_planenv_class(name, domain_name, state):
         return DMControlEnv
     elif "SuperMarioBros" in name:
         return MarioEnv
+    elif "BalloonLearningEnvironment-v0":
+        return BalloonEnv
     raise ValueError(f"Environment {name} is not supported.")
 
 
