@@ -1,5 +1,5 @@
 """Module that contains environments representing video games."""
 from plangym.videogames.atari import AtariEnv  # noqa: E402
-from plangym.videogames.montezuma import Montezuma  # noqa: E402
+from plangym.videogames.montezuma import MontezumaEnv  # noqa: E402
 from plangym.videogames.nes import MarioEnv  # noqa: E402
 from plangym.videogames.retro import RetroEnv  # noqa: E402
